import { message, Space, Upload, Avatar } from "antd"
import { LoadingOutlined, UserOutlined } from "@ant-design/icons";
import { RcFile } from "antd/lib/upload";
import React, { useState } from "react";
import './global.less'
import { useAjax } from "@/Hook/useAjax";
import { getOssInfoApi, updateIconApi } from "@/services/iaaSystem/application";
import request from "umi-request";

interface Props {
    id: number
    value?: string,  // 图片地址
    onChange?: () => void,
}
const MyUpload: React.FC<Props> = (props) => {

    /** 变量START */
    const { value, id, onChange } = props
    const [imageFile, setImageFile] = useState<string>(value || '');
    const [loading, setLoading] = useState<boolean>(false)
    /** 变量END */

    const getOssInfo = useAjax((params) => getOssInfoApi(params))
    const updateIcon = useAjax((params) => updateIconApi(params))

    const beforeUpload = async (file: RcFile) => {
        const isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';
        if (!isJpgOrPng) {
            message.error('您只能上传JPG/PNG文件！');
        }
        const isLt2M = file.size / 1024 / 1024 < 10;
        if (!isLt2M) {
            message.error('图像必须小于2MB！');
        }
        return isJpgOrPng && isLt2M;
    };

    const uploadButton = (
        <div>
            {loading ? <LoadingOutlined /> : <UserOutlined />}
        </div>
    );

    return <div className="myUpload">
        <Space align="start">
            <Upload
                name="avatar"
                listType="picture-card"
                accept='image/gif,image/jpeg,image/png,image/jpg'
                className="avatar-uploader"
                beforeUpload={beforeUpload}
                maxCount={1}
                showUploadList={false}
                customRequest={(options: any) => {
                    setLoading(true)
                    getOssInfo.run({ type: 'image/jpeg', fileType: 'image' }).then(async res => {
                        if (res && (typeof res === 'object') && res?.data) {
                            let formData = new FormData();
                            Object.keys(res.data).forEach((key: string) => {
                                if (key !== 'url') {
                                    formData.append(key, res.data[key])
                                }
                            })
                            formData.append('file', options.file)
                            let urlData = await request(res?.data?.ossUrl, { method: 'POST', data: formData }).catch(err => setLoading(false))
                            setImageFile(urlData?.data?.url);
                            if (urlData?.data?.url) {
                                updateIcon.run({id, icon: urlData?.data?.url}).then(res => {
                                    setLoading(false)
                                    if (res?.data) {
                                        message.success('上传成功')
                                        onChange?.()
                                    }
                                }).catch(() => setLoading(false))
                            } else {
                                setLoading(false)
                            }
                        }
                    })
                }}
            >
                {imageFile ? <Avatar shape="square" size="small" icon={<UserOutlined />} src={imageFile} /> : uploadButton}
            </Upload>
        </Space>
    </div>
}


export default React.memo(MyUpload)