import { getAppTrendListApi, GetAppTrendListProps, getAppTrendTotalApi } from "@/services/iaaData";
import React, { useEffect, useState } from "react"
import { useModel } from "umi";
import moment from "moment";
import { useAjax } from "@/Hook/useAjax";
import TablePro from "@/components/TablePro";
import QueryForm from "@/components/QueryForm";
import columns12 from "./tableConfig";

/**
 * 应用变现趋势
 * @returns 
 */
const AppCashTrend: React.FC = () => {

    /****************************************/
    const { initialState } = useModel('@@initialState');
    const [queryForm, setQueryForm] = useState<GetAppTrendListProps>({
        pageNum: 1,
        pageSize: 30,
        costDayBegin: moment().subtract(1, 'days').format('YYYY-MM-DD'),
        costDayEnd: moment().subtract(1, 'days').format('YYYY-MM-DD'),
    })
    const [totalData, setTotalData] = useState<any[]>([])

    const getAppTrendList = useAjax((params) => getAppTrendListApi(params))
    const getAppTrendTotal = useAjax((params) => getAppTrendTotalApi(params))
    /****************************************/

    useEffect(() => {
        if (initialState?.iaaApp) {
            const [appId, productType] = initialState.iaaApp.split('||')
            getAppTrendList.run({ ...queryForm, appId, productType })
            getAppTrendTotal.run({ ...queryForm, appId, productType }).then((res: { data: { id: number; dt: string, costDayBegin: string } }) => {
                if (res?.data) {
                    let data = res?.data
                    data.id = 1
                    data.costDayBegin = queryForm?.costDayBegin || moment().format('YYYY-MM-DD')
                    data.dt = '总计'
                    setTotalData([data])
                } else {
                    setTotalData([{ id: 1, dt: '总计' }])
                }
            })
        }

    }, [queryForm, initialState?.iaaApp])

    return <div>
        <TablePro
            leftChild={<QueryForm
                initialValues={{ day1: [moment().subtract(1, 'days'), moment().subtract(1, 'days')] }}
                day1={{ placeholder: ['消耗日期开始', '消耗日期结束'] }}
                onChange={(data: any) => {
                    console.log(data)
                    const { day1, ...params } = data
                    let newQueryForm = JSON.parse(JSON.stringify(queryForm))
                    newQueryForm.pageNum = 1
                    if (day1 && day1?.length === 2) {
                        newQueryForm['costDayBegin'] = moment(day1[0]).format('YYYY-MM-DD')
                        newQueryForm['costDayEnd'] = moment(day1[1]).format('YYYY-MM-DD')
                    } else {
                        delete newQueryForm['costDayBegin']
                        delete newQueryForm['costDayEnd']
                    }
                    setQueryForm({ ...newQueryForm, ...params })
                }}
            />}
            isZj
            totalData={totalData}
            config={columns12()}
            configName={'应用变现趋势'}
            fixed={{ left: 4, right: 0 }}
            scroll={{ x: 1000, y: 620 }}
            title='应用变现趋势'
            loading={getAppTrendList.loading}
            ajax={getAppTrendList}
            page={getAppTrendList?.data?.data?.current || 1}
            pageSize={getAppTrendList?.data?.data?.size || 20}
            total={getAppTrendList?.data?.data?.total || 0}
            dataSource={getAppTrendList?.data?.data?.records?.map((item: any, index: number) => ({ ...item, id: Number(queryForm.pageNum.toString() + (index + '')) }))}
            onChange={(pagination: any, _: any, sortData: any) => {
                let { current, pageSize } = pagination
                let newQueryForm = JSON.parse(JSON.stringify(queryForm))
                if (sortData && sortData?.order) {
                    newQueryForm['sortAsc'] = sortData?.order === 'ascend' ? true : false
                    newQueryForm['sortFiled'] = sortData?.field
                } else {
                    delete newQueryForm['sortAsc']
                    delete newQueryForm['sortFiled']
                }
                newQueryForm.pageNum = current || newQueryForm.pageNum
                newQueryForm.pageSize = pageSize || newQueryForm.pageSize
                setQueryForm({ ...newQueryForm })
            }}
        />
    </div>
}

export default AppCashTrend