import { AjaxPromise, useAjax } from "@/Hook/useAjax";
import { iaaConfigBackPolicyBackApi } from "@/services/iaaSystem/channel";
import { Form, message, Modal, Select } from "antd";
import React from "react"


interface Props {
    getBackPolicyAllList: AjaxPromise,
    selectedRows: any[]
    onChange?: () => void
    visible?: boolean
    onClose?: () => void
}

/**
 * 新增修改回传策略
 * @returns 
 */
const ConfigBackPolicy: React.FC<Props> = ({ onChange, visible, onClose, selectedRows, getBackPolicyAllList }) => {

    /*******************************/
    const [form] = Form.useForm<IAAAPI.AddIaaAgentProps>();

    const iaaConfigBackPolicyBack = useAjax((params) => iaaConfigBackPolicyBackApi(params))
    /*******************************/


    const handleOk = async () => {
        form.submit()
        let data: any = await form.validateFields()
        iaaConfigBackPolicyBack.run({...data, agentIds: selectedRows.map(item => item.id).toString()}).then(res => {
            if (res?.data) {
                message.success('修改成功')
                onChange && onChange()
            }
        })
    }

    return <Modal
        title={<strong>{'修改回传策略'}</strong>}
        open={visible}
        onCancel={onClose}
        onOk={handleOk}
        confirmLoading={iaaConfigBackPolicyBack.loading}
    >
        <Form
            name="configBackPolicy"
            layout="vertical"
            form={form}
            autoComplete="off"
            colon={false}
        >
            <Form.Item label={<strong>回传策略</strong>} name="backPolicyId">
                <Select
                    placeholder="请选择回传策略"
                    allowClear
                    options={getBackPolicyAllList?.data?.data?.map((item: { id: any; backPolicyName: any; }) => ({
                        value: item.id,
                        label: item.backPolicyName,
                    }))}
                />
            </Form.Item>
        </Form>
    </Modal>
}

export default React.memo(ConfigBackPolicy)