import { useAjax } from "@/Hook/useAjax";
import { getIaaAgentListApi } from "@/services/iaaSystem/channel";
import { PlusOutlined } from "@ant-design/icons"
import ProTable, { ActionType } from "@ant-design/pro-table";
import { Button, Space, Table } from "antd"
import React, { useEffect, useRef, useState } from "react"
import tableConfig from "./tableConfig";
import ModalChannel from "./modalChannel";
import { getBackPolicyAllListApi } from "@/services/iaaSystem/backPolicy";
import ConfigPutStatus from "./configPutStatus";
import ConfigBackPolicy from "./configBackPolicy";
import { getAllOfOwnerUserApi, getTtAllUserListApi } from "@/services/iaaSystem";
import { getAppAuthListApi } from "@/services/iaaSystem/application";
import { DefaultOptionType } from "antd/lib/select";
import { copy } from "@/utils/utils";


/**
 * 渠道
 * @returns 
 */
const Channel: React.FC = () => {

    /***************************************/
    const actionRef = useRef<ActionType>();
    const [visible, setVisible] = useState<boolean>(false)
    const [initialValues, setInitialValues] = useState<any>()
    const [backValueEnum, setBackValueEnum] = useState<any>({})
    const [selectedRows, setSelectedRows] = useState<any[]>([])
    const [putStatusVisible, setPutStatusVisible] = useState<boolean>(false)
    const [backPolicyVisible, setBackPolicyVisible] = useState<boolean>(false)
    const [appList, setAppList] = useState<DefaultOptionType[]>([])
    const [appObj, setAppObj] = useState<any>({})

    const getFolderList = useAjax((params) => getIaaAgentListApi(params), { type: 'table' })
    const getBackPolicyAllList = useAjax(() => getBackPolicyAllListApi())
    const getAllOfOwnerUser = useAjax(() => getAllOfOwnerUserApi())
    const getTtAllUserList = useAjax(() => getTtAllUserListApi())
    const getAppAuthList = useAjax(() => getAppAuthListApi())
    /***************************************/


    useEffect(() => {
        getBackPolicyAllList.run().then(res => {
            console.log(res)
            let newBackValueEnum: any = {}
            res?.data?.forEach((item: any) => {
                newBackValueEnum[item.id] = item.backPolicyName
            })
            setBackValueEnum(newBackValueEnum)
        })
        getAllOfOwnerUser.run()
        getTtAllUserList.run()
        getAppAuthList.run().then(res => {
            if (res?.data) {
                let newAppList: DefaultOptionType[] = []
                let newAppObj: any = {}
                res.data?.third.forEach((item: { name: any; id: any; }) => {
                    newAppList.push({ label: item.name, value: item.id })
                    newAppObj[item.id] = {
                        text: item.name
                    }
                })
                setAppList(newAppList)
                setAppObj(newAppObj)
            }
        })
    }, [])

    // 变更投放状态
    const handlePutStatus = () => {
        setPutStatusVisible(true)
    }

    return <>
        <ProTable<any>
            columns={tableConfig(backValueEnum, appObj)}
            actionRef={actionRef}
            cardBordered
            request={async (params, sort, filter) => {
                console.log(sort, filter);
                return await getFolderList.run(params)
            }}
            editable={{
                type: 'multiple',
            }}
            rowKey="id"
            search={{
                labelWidth: 'auto',
            }}
            headerTitle={<strong>推广渠道</strong>}
            toolBarRender={() => [
                <Button type="primary" style={{ backgroundColor: '#FF9100', border: '#FF9100' }} onClick={() => copy('https://game.84game.cn/iaaSdk/api/listen/link/oceanengine/callback?promotionId=__PROMOTION_ID__&projectId=__PROJECT_ID__&mid1=__MID1__&mid2=__MID2__&mid3=__MID3__&mid4=__MID4__&mid5=__MID5__&mid6=__MID6__&aid=__AID__&cid=__CID__&campaignId=__CAMPAIGN_ID__&ctype=__CTYPE__&advertiserId=__ADVERTISER_ID__&csite=__CSITE__&convertId=__CONVERT_ID__&requestId=__REQUEST_ID__&trackId=__TRACK_ID__&sl=__SL__&idfa=__IDFA__&idfaMd5=__IDFA_MD5__&androidid=__ANDROIDID__&oaid=__OAID__&oaidMd5=__OAID_MD5__&os=__OS__&mac=__MAC__&mac1=MAC1&ipv4=__IPV4__&ip=__IP__&ua=__UA__&geo=__GEO__&ts=__TS__&callbackParam=__CALLBACK_PARAM__&callbackUrl=__CALLBACK_URL__&model=__MODEL__&unionSite=__UNION_SITE__&caid=__CAID__&outerid=__OUTERID__')}>
                    复制头条推广链接
                </Button>,
                <Button type="primary" onClick={() => {
                    setVisible(true)
                }}>
                    <PlusOutlined />
                    新建
                </Button>
            ]}
            scroll={{ x: 1200 }}
            rowSelection={{
                // 自定义选择项参考: https://ant.design/components/table-cn/#components-table-demo-row-selection-custom
                // 注释该行则默认不显示下拉选项
                selections: [Table.SELECTION_ALL, Table.SELECTION_INVERT],
                onChange(_, selectedRows) {
                    setSelectedRows(selectedRows)
                },
            }}
            tableAlertRender={({
                selectedRowKeys,
                selectedRows,
                onCleanSelected,
            }) => {
                return (
                    <Space size={24}>
                        <span>
                            已选 {selectedRowKeys.length} 项
                            <a style={{ marginInlineStart: 8 }} onClick={onCleanSelected}>
                                取消选择
                            </a>
                        </span>
                    </Space>
                );
            }}
            tableAlertOptionRender={() => {
                return (
                    <Space size={16}>
                        <a onClick={handlePutStatus}>变更投放状态</a>
                        <a onClick={() => setBackPolicyVisible(true)}>修改回传策略</a>
                    </Space>
                );
            }}
        />

        {/* 新增修改 */}
        {visible && <ModalChannel
            appList={appList}
            getAllOfOwnerUser={getAllOfOwnerUser}
            getTtAllUserList={getTtAllUserList}
            getBackPolicyAllList={getBackPolicyAllList}
            visible={visible}
            initialValues={initialValues}
            onChange={() => {
                setVisible(false)
                setInitialValues(undefined)
                actionRef.current?.reload()
            }}
            onClose={() => {
                setVisible(false)
                setInitialValues(undefined)
            }}
        />}

        {/* 变更状态 */}
        {putStatusVisible && <ConfigPutStatus
            selectedRows={selectedRows}
            visible={putStatusVisible}
            onChange={() => {
                setPutStatusVisible(false)
                actionRef.current?.reload();
                (actionRef.current as any)?.clearSelected()
            }}
            onClose={() => {
                (actionRef.current as any)?.clearSelected()
                setPutStatusVisible(false)
            }}
        />}

        {/* 修改回传策略 */}
        {backPolicyVisible && <ConfigBackPolicy
            getBackPolicyAllList={getBackPolicyAllList}
            selectedRows={selectedRows}
            visible={backPolicyVisible}
            onChange={() => {
                setBackPolicyVisible(false)
                actionRef.current?.reload();
                (actionRef.current as any)?.clearSelected()
            }}
            onClose={() => {
                (actionRef.current as any)?.clearSelected()
                setBackPolicyVisible(false)
            }}
        />}
    </>
}

export default Channel