import { AjaxPromise, useAjax } from "@/Hook/useAjax";
import { addIaaAgentApi } from "@/services/iaaSystem/channel";
import { Form, Input, message, Modal, Select } from "antd";
import { DefaultOptionType } from "antd/lib/select";
import React from "react"


interface Props {
    getBackPolicyAllList: AjaxPromise
    getAllOfOwnerUser: AjaxPromise
    getTtAllUserList: AjaxPromise
    appList: DefaultOptionType[]
    onChange?: () => void
    visible?: boolean
    onClose?: () => void
    initialValues?: any
}

/**
 * 新增修改回传策略
 * @returns 
 */
const ModalChannel: React.FC<Props> = ({ onChange, visible, onClose, initialValues, appList, getBackPolicyAllList, getAllOfOwnerUser, getTtAllUserList }) => {

    /*******************************/
    const [form] = Form.useForm<IAAAPI.AddIaaAgentProps>();
    const accountType = Form.useWatch('accountType', form)

    const addIaaAgent = useAjax((params) => addIaaAgentApi(params))
    /*******************************/


    const handleOk = async () => {
        form.submit()
        let data: any = await form.validateFields()
        if (data.accountType === 'OUTSIDE_APPLICATION' || data.accountType === 'OCENAENGINE_MINI_GAME') {
            data.accountIdList = data.accountIdList.replace(/[,，\s]/g, ',')
            data.accountIdList = data.accountIdList.split(',')
        }
        addIaaAgent.run(data).then(res => {
            if (res?.data) {
                message.success('新增成功')
                onChange && onChange()
            }
        })
    }

    return <Modal
        title={<strong>{initialValues?.id ? '修改渠道' : '新增渠道'}</strong>}
        open={visible}
        onCancel={onClose}
        onOk={handleOk}
        confirmLoading={addIaaAgent.loading}
    >
        <Form
            name="basicChannel"
            layout="vertical"
            form={form}
            autoComplete="off"
            colon={false}
            initialValues={{ ...initialValues }}
        >
            <Form.Item label={<strong>渠道名称</strong>} name="agentName" rules={[{ required: true, message: '请输入策略名称!' }]}>
                <Input min={0} placeholder="请输入策略名称" />
            </Form.Item>
            <Form.Item label={<strong>推广账号类型</strong>} name="accountType" rules={[{ required: true, message: '请选择推广账号类型!' }]}>
                <Select
                    placeholder="请选择推广账号类型"
                    options={[
                        {
                            value: 'OUTSIDE_APPLICATION',
                            label: '外部应用',
                        },
                        {
                            value: 'TENCENT_MINI_GAME',
                            label: '腾讯小游戏',
                        },
                        {
                            value: 'OCENAENGINE_MINI_GAME',
                            label: '头条小游戏',
                        }
                    ]}
                />
            </Form.Item>
            {accountType && <Form.Item label={<strong>广告账号</strong>} name="accountIdList" rules={[{ required: true, message: '请输入广告账号!' }]}>
                {['TENCENT_MINI_GAME'].includes(accountType) ? <Select
                    placeholder="请选择广告账号"
                    mode="multiple"
                    filterOption={(input, option) =>
                        ((option?.label ?? '') as any).toLowerCase().includes(input.toLowerCase())
                    }
                    options={accountType === 'TENCENT_MINI_GAME' ? getAllOfOwnerUser?.data?.data?.map((item: { memo: string; accountId: any; }) => ({
                        value: item.accountId,
                        label: item.accountId + (item.memo ? '_' + item.memo : '')
                    })) : getTtAllUserList?.data?.data?.map((item: { groupName: string; accountName: string; accountId: any; }) => ({
                        value: item.accountId,
                        label: item.accountId + '_' + item.accountName + (item.groupName ? '_' + item.groupName : ''),
                    }))}
                /> : <Input.TextArea placeholder="请输入广告账号(多个逗号，换行隔开)" />}
            </Form.Item>}
            <Form.Item label={<strong>应用</strong>} name="iaaAppId" rules={[{ required: true, message: '请选择应用!' }]}>
                <Select
                    placeholder="请选择应用"
                    filterOption={(input, option) =>
                        ((option?.label ?? '') as any).toLowerCase().includes(input.toLowerCase())
                    }
                    allowClear
                    options={appList}
                />
            </Form.Item>
            <Form.Item label={<strong>投放状态</strong>} name="putStatus" rules={[{ required: true, message: '请选择投放状态!' }]}>
                <Select
                    placeholder="请选择投放状态"
                    options={[
                        {
                            value: 'PUT_STATUS_PUT_ING',
                            label: '投放中',
                        },
                        {
                            value: 'PUT_STATUS_PUT_STOP',
                            label: '投放结束',
                        }
                    ]}
                />
            </Form.Item>
            <Form.Item label={<strong>回传策略</strong>} name="backPolicyId">
                <Select
                    placeholder="请选择回传策略"
                    options={getBackPolicyAllList?.data?.data?.map((item: { id: any; backPolicyName: any; }) => ({
                        value: item.id,
                        label: item.backPolicyName,
                    }))}
                />
            </Form.Item>
        </Form>
    </Modal>
}

export default React.memo(ModalChannel)